package Dist::Zilla::MintingProfile::Author::CSSON;

our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
our $VERSION = '0.1103';

use Moose;
with 'Dist::Zilla::Role::MintingProfile::ShareDir';

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Dist::Zilla::MintingProfile::Author::CSSON

=head1 VERSION

Version 0.1103, released 2016-02-18.

=head1 STATUS

Deprecated. See L<Dist::Zilla::MintingProfile::Iller::CSSON> instead.

=head1 SOURCE

Source repository is at L<https://github.com/CSSON/p5-Dist-Zilla-PluginBundle-Author-CSSON>.

=head1 HOMEPAGE

L<https://metacpan.org/release/Dist-Zilla-PluginBundle-Author-CSSON>

=head1 AUTHOR

Erik Carlsson <info@code301.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by Erik Carlsson.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
